@@ -27,7 +27,9 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 	ß_is_set := πg.InternStr("_is_set")
 	ß_mutex := πg.InternStr("_mutex")
 	ß_run := πg.InternStr("_run")
+	ß_set := πg.InternStr("_set")
 	ß_target := πg.InternStr("_target")
+	ßclear := πg.InternStr("clear")
 	ßjoin := πg.InternStr("join")
 	ßnew := πg.InternStr("new")
 	ßobject := πg.InternStr("object")
@@ -125,6 +127,10 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 			_ = πTemp003
 			var πTemp004 *πg.Object
 			_ = πTemp004
+			var πTemp005 *πg.Object
+			_ = πTemp005
+			var πTemp006 *πg.Object
+			_ = πTemp006
 			var πE *πg.BaseException; _ = πE
 			for ; πF.State() >= 0; πF.PopCheckpoint() {
 				switch πF.State() {
@@ -224,89 +230,35 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 				πTemp002[0] = πg.Param{Name: "self", Def: nil}
 				πTemp003 = πg.NewFunction(πg.NewCode("set", "build/src/__python__/threading.py", πTemp002, 0, func(πF *πg.Frame, πArgs []*πg.Object) (*πg.Object, *πg.BaseException) {
 					var µself *πg.Object = πArgs[0]; _ = µself
-					var πTemp001 *πg.Object
+					var πTemp001 []*πg.Object
 					_ = πTemp001
 					var πTemp002 *πg.Object
 					_ = πTemp002
-					var πTemp003 *πg.BaseException
+					var πTemp003 *πg.Object
 					_ = πTemp003
-					var πTemp004 *πg.Traceback
-					_ = πTemp004
 					var πE *πg.BaseException; _ = πE
 					for ; πF.State() >= 0; πF.PopCheckpoint() {
 						switch πF.State() {
 						case 0:
-						case 1: goto Label1
 						default: panic("unexpected function state")
 						}
-						// line 30: self._mutex.Lock()
+						// line 30: self._set(True)
 						πF.SetLineno(30)
+						πTemp001 = πF.MakeArgs(1)
+						if πTemp002, πE = πg.ResolveGlobal(πF, ßTrue); πE != nil {
+							continue
+						}
+						πTemp001[0] = πTemp002
 						if πE = πg.CheckLocal(πF, µself, "self"); πE != nil {
 							continue
 						}
-						if πTemp001, πE = πg.GetAttr(πF, µself, ß_mutex, nil); πE != nil {
+						if πTemp002, πE = πg.GetAttr(πF, µself, ß_set, nil); πE != nil {
 							continue
 						}
-						if πTemp002, πE = πg.GetAttr(πF, πTemp001, ßLock, nil); πE != nil {
-							continue
-						}
-						if πTemp001, πE = πTemp002.Call(πF, nil, nil); πE != nil {
-							continue
-						}
-						// line 31: try:
-						πF.SetLineno(31)
-						πF.PushCheckpoint(1)
-						// line 32: self._is_set = True
-						πF.SetLineno(32)
-						if πTemp001, πE = πg.ResolveGlobal(πF, ßTrue); πE != nil {
-							continue
-						}
-						if πE = πg.Tie(πF, πg.TieTarget{Target: &πTemp002}, πTemp001); πE != nil {
-							continue
-						}
-						if πE = πg.CheckLocal(πF, µself, "self"); πE != nil {
-							continue
-						}
-						if πE = πg.SetAttr(πF, µself, ß_is_set, πTemp002); πE != nil {
-							continue
-						}
-						πF.PopCheckpoint()
-						goto Label1
-					Label1:
-						πE = nil
-						πTemp003, πTemp004 = πF.RestoreExc(nil, nil)
-						// line 34: self._mutex.Unlock()
-						πF.SetLineno(34)
-						if πE = πg.CheckLocal(πF, µself, "self"); πE != nil {
-							continue
-						}
-						if πTemp001, πE = πg.GetAttr(πF, µself, ß_mutex, nil); πE != nil {
-							continue
-						}
-						if πTemp002, πE = πg.GetAttr(πF, πTemp001, ßUnlock, nil); πE != nil {
-							continue
-						}
-						if πTemp001, πE = πTemp002.Call(πF, nil, nil); πE != nil {
-							continue
-						}
-						if πTemp003 != nil {
-							πE = πF.Raise(πTemp003.ToObject(), nil, πTemp004.ToObject())
-							continue
-						}
-						// line 35: self._cond.Broadcast()
-						πF.SetLineno(35)
-						if πE = πg.CheckLocal(πF, µself, "self"); πE != nil {
-							continue
-						}
-						if πTemp001, πE = πg.GetAttr(πF, µself, ß_cond, nil); πE != nil {
-							continue
-						}
-						if πTemp002, πE = πg.GetAttr(πF, πTemp001, ßBroadcast, nil); πE != nil {
-							continue
-						}
-						if πTemp001, πE = πTemp002.Call(πF, nil, nil); πE != nil {
+						if πTemp003, πE = πTemp002.Call(πF, πTemp001, nil); πE != nil {
 							continue
 						}
+						πF.FreeArgs(πTemp001)
 						return nil, nil
 					}
 					return nil, πE
@@ -314,11 +266,53 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 				if πE = πClass.SetItem(πF, ßset.ToObject(), πTemp003); πE != nil {
 					continue
 				}
-				// line 38: def wait(self):
-				πF.SetLineno(38)
+				// line 32: def clear(self):
+				πF.SetLineno(32)
 				πTemp002 = make([]πg.Param, 1)
 				πTemp002[0] = πg.Param{Name: "self", Def: nil}
-				πTemp004 = πg.NewFunction(πg.NewCode("wait", "build/src/__python__/threading.py", πTemp002, 0, func(πF *πg.Frame, πArgs []*πg.Object) (*πg.Object, *πg.BaseException) {
+				πTemp004 = πg.NewFunction(πg.NewCode("clear", "build/src/__python__/threading.py", πTemp002, 0, func(πF *πg.Frame, πArgs []*πg.Object) (*πg.Object, *πg.BaseException) {
+					var µself *πg.Object = πArgs[0]; _ = µself
+					var πTemp001 []*πg.Object
+					_ = πTemp001
+					var πTemp002 *πg.Object
+					_ = πTemp002
+					var πTemp003 *πg.Object
+					_ = πTemp003
+					var πE *πg.BaseException; _ = πE
+					for ; πF.State() >= 0; πF.PopCheckpoint() {
+						switch πF.State() {
+						case 0:
+						default: panic("unexpected function state")
+						}
+						// line 33: self._set(False)
+						πF.SetLineno(33)
+						πTemp001 = πF.MakeArgs(1)
+						if πTemp002, πE = πg.ResolveGlobal(πF, ßFalse); πE != nil {
+							continue
+						}
+						πTemp001[0] = πTemp002
+						if πE = πg.CheckLocal(πF, µself, "self"); πE != nil {
+							continue
+						}
+						if πTemp002, πE = πg.GetAttr(πF, µself, ß_set, nil); πE != nil {
+							continue
+						}
+						if πTemp003, πE = πTemp002.Call(πF, πTemp001, nil); πE != nil {
+							continue
+						}
+						πF.FreeArgs(πTemp001)
+						return nil, nil
+					}
+					return nil, πE
+				}), πF.Globals()).ToObject()
+				if πE = πClass.SetItem(πF, ßclear.ToObject(), πTemp004); πE != nil {
+					continue
+				}
+				// line 36: def wait(self):
+				πF.SetLineno(36)
+				πTemp002 = make([]πg.Param, 1)
+				πTemp002[0] = πg.Param{Name: "self", Def: nil}
+				πTemp005 = πg.NewFunction(πg.NewCode("wait", "build/src/__python__/threading.py", πTemp002, 0, func(πF *πg.Frame, πArgs []*πg.Object) (*πg.Object, *πg.BaseException) {
 					var µself *πg.Object = πArgs[0]; _ = µself
 					var πTemp001 *πg.Object
 					_ = πTemp001
@@ -339,8 +333,8 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 						case 1: goto Label1
 						default: panic("unexpected function state")
 						}
-						// line 39: self._mutex.Lock()
-						πF.SetLineno(39)
+						// line 37: self._mutex.Lock()
+						πF.SetLineno(37)
 						if πE = πg.CheckLocal(πF, µself, "self"); πE != nil {
 							continue
 						}
@@ -353,11 +347,11 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 						if πTemp001, πE = πTemp002.Call(πF, nil, nil); πE != nil {
 							continue
 						}
-						// line 40: try:
-						πF.SetLineno(40)
+						// line 38: try:
+						πF.SetLineno(38)
 						πF.PushCheckpoint(1)
-						// line 41: while not self._is_set:
-						πF.SetLineno(41)
+						// line 39: while not self._is_set:
+						πF.SetLineno(39)
 					Label2:
 						if πE = πg.CheckLocal(πF, µself, "self"); πE != nil {
 							continue
@@ -375,8 +369,8 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 						if !πTemp003 {
 							goto Label3
 						}
-						// line 42: self._cond.Wait()
-						πF.SetLineno(42)
+						// line 40: self._cond.Wait()
+						πF.SetLineno(40)
 						if πE = πg.CheckLocal(πF, µself, "self"); πE != nil {
 							continue
 						}
@@ -397,8 +391,8 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 					Label1:
 						πE = nil
 						πTemp005, πTemp006 = πF.RestoreExc(nil, nil)
-						// line 44: self._mutex.Unlock()
-						πF.SetLineno(44)
+						// line 42: self._mutex.Unlock()
+						πF.SetLineno(42)
 						if πE = πg.CheckLocal(πF, µself, "self"); πE != nil {
 							continue
 						}
@@ -415,8 +409,8 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 							πE = πF.Raise(πTemp005.ToObject(), nil, πTemp006.ToObject())
 							continue
 						}
-						// line 45: return True
-						πF.SetLineno(45)
+						// line 43: return True
+						πF.SetLineno(43)
 						if πTemp001, πE = πg.ResolveGlobal(πF, ßTrue); πE != nil {
 							continue
 						}
@@ -425,7 +419,105 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 					}
 					return nil, πE
 				}), πF.Globals()).ToObject()
-				if πE = πClass.SetItem(πF, ßwait.ToObject(), πTemp004); πE != nil {
+				if πE = πClass.SetItem(πF, ßwait.ToObject(), πTemp005); πE != nil {
+					continue
+				}
+				// line 45: def _set(self, is_set):
+				πF.SetLineno(45)
+				πTemp002 = make([]πg.Param, 2)
+				πTemp002[0] = πg.Param{Name: "self", Def: nil}
+				πTemp002[1] = πg.Param{Name: "is_set", Def: nil}
+				πTemp006 = πg.NewFunction(πg.NewCode("_set", "build/src/__python__/threading.py", πTemp002, 0, func(πF *πg.Frame, πArgs []*πg.Object) (*πg.Object, *πg.BaseException) {
+					var µself *πg.Object = πArgs[0]; _ = µself
+					var µis_set *πg.Object = πArgs[1]; _ = µis_set
+					var πTemp001 *πg.Object
+					_ = πTemp001
+					var πTemp002 *πg.Object
+					_ = πTemp002
+					var πTemp003 *πg.BaseException
+					_ = πTemp003
+					var πTemp004 *πg.Traceback
+					_ = πTemp004
+					var πE *πg.BaseException; _ = πE
+					for ; πF.State() >= 0; πF.PopCheckpoint() {
+						switch πF.State() {
+						case 0:
+						case 1: goto Label1
+						default: panic("unexpected function state")
+						}
+						// line 46: self._mutex.Lock()
+						πF.SetLineno(46)
+						if πE = πg.CheckLocal(πF, µself, "self"); πE != nil {
+							continue
+						}
+						if πTemp001, πE = πg.GetAttr(πF, µself, ß_mutex, nil); πE != nil {
+							continue
+						}
+						if πTemp002, πE = πg.GetAttr(πF, πTemp001, ßLock, nil); πE != nil {
+							continue
+						}
+						if πTemp001, πE = πTemp002.Call(πF, nil, nil); πE != nil {
+							continue
+						}
+						// line 47: try:
+						πF.SetLineno(47)
+						πF.PushCheckpoint(1)
+						// line 48: self._is_set = is_set
+						πF.SetLineno(48)
+						if πE = πg.CheckLocal(πF, µis_set, "is_set"); πE != nil {
+							continue
+						}
+						if πE = πg.Tie(πF, πg.TieTarget{Target: &πTemp001}, µis_set); πE != nil {
+							continue
+						}
+						if πE = πg.CheckLocal(πF, µself, "self"); πE != nil {
+							continue
+						}
+						if πE = πg.SetAttr(πF, µself, ß_is_set, πTemp001); πE != nil {
+							continue
+						}
+						πF.PopCheckpoint()
+						goto Label1
+					Label1:
+						πE = nil
+						πTemp003, πTemp004 = πF.RestoreExc(nil, nil)
+						// line 50: self._mutex.Unlock()
+						πF.SetLineno(50)
+						if πE = πg.CheckLocal(πF, µself, "self"); πE != nil {
+							continue
+						}
+						if πTemp001, πE = πg.GetAttr(πF, µself, ß_mutex, nil); πE != nil {
+							continue
+						}
+						if πTemp002, πE = πg.GetAttr(πF, πTemp001, ßUnlock, nil); πE != nil {
+							continue
+						}
+						if πTemp001, πE = πTemp002.Call(πF, nil, nil); πE != nil {
+							continue
+						}
+						if πTemp003 != nil {
+							πE = πF.Raise(πTemp003.ToObject(), nil, πTemp004.ToObject())
+							continue
+						}
+						// line 51: self._cond.Broadcast()
+						πF.SetLineno(51)
+						if πE = πg.CheckLocal(πF, µself, "self"); πE != nil {
+							continue
+						}
+						if πTemp001, πE = πg.GetAttr(πF, µself, ß_cond, nil); πE != nil {
+							continue
+						}
+						if πTemp002, πE = πg.GetAttr(πF, πTemp001, ßBroadcast, nil); πE != nil {
+							continue
+						}
+						if πTemp001, πE = πTemp002.Call(πF, nil, nil); πE != nil {
+							continue
+						}
+						return nil, nil
+					}
+					return nil, πE
+				}), πF.Globals()).ToObject()
+				if πE = πClass.SetItem(πF, ß_set.ToObject(), πTemp006); πE != nil {
 					continue
 				}
 				return nil, nil
@@ -447,8 +539,8 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 		if πE = πF.Globals().SetItem(πF, ßEvent.ToObject(), πTemp007); πE != nil {
 			continue
 		}
-		// line 48: class Thread(object):
-		πF.SetLineno(48)
+		// line 54: class Thread(object):
+		πF.SetLineno(54)
 		πTemp006 = make([]*πg.Object, 1)
 		if πTemp007, πE = πg.ResolveGlobal(πF, ßobject); πE != nil {
 			continue
@@ -482,10 +574,10 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 				case 0:
 				default: panic("unexpected function state")
 				}
-				// line 49: """Thread is an activity to be executed concurrently."""
-				πF.SetLineno(49)
-				// line 51: def __init__(self, target=None, args=()):
-				πF.SetLineno(51)
+				// line 55: """Thread is an activity to be executed concurrently."""
+				πF.SetLineno(55)
+				// line 57: def __init__(self, target=None, args=()):
+				πF.SetLineno(57)
 				πTemp002 = make([]πg.Param, 3)
 				πTemp002[0] = πg.Param{Name: "self", Def: nil}
 				if πTemp003, πE = πg.ResolveClass(πF, πClass, nil, ßNone); πE != nil {
@@ -508,8 +600,8 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 						case 0:
 						default: panic("unexpected function state")
 						}
-						// line 52: self._target = target
-						πF.SetLineno(52)
+						// line 58: self._target = target
+						πF.SetLineno(58)
 						if πE = πg.CheckLocal(πF, µtarget, "target"); πE != nil {
 							continue
 						}
@@ -522,8 +614,8 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 						if πE = πg.SetAttr(πF, µself, ß_target, πTemp001); πE != nil {
 							continue
 						}
-						// line 53: self._args = args
-						πF.SetLineno(53)
+						// line 59: self._args = args
+						πF.SetLineno(59)
 						if πE = πg.CheckLocal(πF, µargs, "args"); πE != nil {
 							continue
 						}
@@ -536,8 +628,8 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 						if πE = πg.SetAttr(πF, µself, ß_args, πTemp001); πE != nil {
 							continue
 						}
-						// line 54: self._event = Event()
-						πF.SetLineno(54)
+						// line 60: self._event = Event()
+						πF.SetLineno(60)
 						if πTemp001, πE = πg.ResolveGlobal(πF, ßEvent); πE != nil {
 							continue
 						}
@@ -560,8 +652,8 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 				if πE = πClass.SetItem(πF, ß__init__.ToObject(), πTemp001); πE != nil {
 					continue
 				}
-				// line 56: def run(self):
-				πF.SetLineno(56)
+				// line 62: def run(self):
+				πF.SetLineno(62)
 				πTemp002 = make([]πg.Param, 1)
 				πTemp002[0] = πg.Param{Name: "self", Def: nil}
 				πTemp003 = πg.NewFunction(πg.NewCode("run", "build/src/__python__/threading.py", πTemp002, 0, func(πF *πg.Frame, πArgs []*πg.Object) (*πg.Object, *πg.BaseException) {
@@ -578,8 +670,8 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 						case 0:
 						default: panic("unexpected function state")
 						}
-						// line 57: self._target(*self._args)
-						πF.SetLineno(57)
+						// line 63: self._target(*self._args)
+						πF.SetLineno(63)
 						if πE = πg.CheckLocal(πF, µself, "self"); πE != nil {
 							continue
 						}
@@ -602,8 +694,8 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 				if πE = πClass.SetItem(πF, ßrun.ToObject(), πTemp003); πE != nil {
 					continue
 				}
-				// line 59: def start(self):
-				πF.SetLineno(59)
+				// line 65: def start(self):
+				πF.SetLineno(65)
 				πTemp002 = make([]πg.Param, 1)
 				πTemp002[0] = πg.Param{Name: "self", Def: nil}
 				πTemp004 = πg.NewFunction(πg.NewCode("start", "build/src/__python__/threading.py", πTemp002, 0, func(πF *πg.Frame, πArgs []*πg.Object) (*πg.Object, *πg.BaseException) {
@@ -620,8 +712,8 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 						case 0:
 						default: panic("unexpected function state")
 						}
-						// line 60: StartThread(self._run)
-						πF.SetLineno(60)
+						// line 66: StartThread(self._run)
+						πF.SetLineno(66)
 						πTemp001 = πF.MakeArgs(1)
 						if πE = πg.CheckLocal(πF, µself, "self"); πE != nil {
 							continue
@@ -644,8 +736,8 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 				if πE = πClass.SetItem(πF, ßstart.ToObject(), πTemp004); πE != nil {
 					continue
 				}
-				// line 63: def join(self):
-				πF.SetLineno(63)
+				// line 69: def join(self):
+				πF.SetLineno(69)
 				πTemp002 = make([]πg.Param, 1)
 				πTemp002[0] = πg.Param{Name: "self", Def: nil}
 				πTemp005 = πg.NewFunction(πg.NewCode("join", "build/src/__python__/threading.py", πTemp002, 0, func(πF *πg.Frame, πArgs []*πg.Object) (*πg.Object, *πg.BaseException) {
@@ -660,8 +752,8 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 						case 0:
 						default: panic("unexpected function state")
 						}
-						// line 64: self._event.wait()
-						πF.SetLineno(64)
+						// line 70: self._event.wait()
+						πF.SetLineno(70)
 						if πE = πg.CheckLocal(πF, µself, "self"); πE != nil {
 							continue
 						}
@@ -681,8 +773,8 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 				if πE = πClass.SetItem(πF, ßjoin.ToObject(), πTemp005); πE != nil {
 					continue
 				}
-				// line 66: def _run(self):
-				πF.SetLineno(66)
+				// line 72: def _run(self):
+				πF.SetLineno(72)
 				πTemp002 = make([]πg.Param, 1)
 				πTemp002[0] = πg.Param{Name: "self", Def: nil}
 				πTemp006 = πg.NewFunction(πg.NewCode("_run", "build/src/__python__/threading.py", πTemp002, 0, func(πF *πg.Frame, πArgs []*πg.Object) (*πg.Object, *πg.BaseException) {
@@ -702,11 +794,11 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 						case 1: goto Label1
 						default: panic("unexpected function state")
 						}
-						// line 67: try:
-						πF.SetLineno(67)
+						// line 73: try:
+						πF.SetLineno(73)
 						πF.PushCheckpoint(1)
-						// line 68: self.run()
-						πF.SetLineno(68)
+						// line 74: self.run()
+						πF.SetLineno(74)
 						if πE = πg.CheckLocal(πF, µself, "self"); πE != nil {
 							continue
 						}
@@ -721,8 +813,8 @@ func initModule(πF *πg.Frame, _ []*πg.Object) (*πg.Object, *πg.BaseExceptio
 					Label1:
 						πE = nil
 						πTemp003, πTemp004 = πF.RestoreExc(nil, nil)
-						// line 70: self._event.set()
-						πF.SetLineno(70)
+						// line 76: self._event.set()
+						πF.SetLineno(76)
 						if πE = πg.CheckLocal(πF, µself, "self"); πE != nil {
 							continue
 						}
